# mnist

<!---[![Build Status](https://travis-ci.com/blester125/get-mnist.svg?branch=master)](https://travis-ci.com/blester125/get-mnist)--->

Download MNIST and Fashion MNIST datasets without needing to install tensorflow.
